@@ -4,6 +4,7 @@ import logging
 from contextlib import suppress
 from typing import TYPE_CHECKING
 
+from clinicedc_constants import CLOSED, NEW, OPEN
 from django.apps import apps as django_apps
 from django.conf import settings
 from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist
@@ -12,7 +13,6 @@ from django.db import models
 from django.utils.formats import localize
 
 from edc_action_item.stubs import ActionItemStub
-from edc_constants.constants import CLOSED, NEW, OPEN
 from edc_model.constants import DEFAULT_BASE_FIELDS
 from edc_sites.utils import valid_site_for_subject_or_raise
 
