@@ -1,7 +1,6 @@
+from clinicedc_constants import NEW
 from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist
 
-from edc_constants.constants import NEW
-
 from .get_action_type import get_action_type
 
 
