@@ -1,7 +1,7 @@
+from clinicedc_constants import CANCELLED, NEW, OPEN
 from django import forms
 from django.apps import apps as django_apps
 
-from edc_constants.constants import CANCELLED, NEW, OPEN
 from edc_model_form.mixins import BaseModelFormMixin
 
 from ..models import ActionItem
