@@ -1,11 +1,11 @@
 from typing import Any
 
+from clinicedc_constants import CLOSED, NEW, OPEN
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models.signals import m2m_changed, post_delete, post_save
 from django.dispatch import receiver
 from simple_history.signals import post_create_historical_record
 
-from edc_constants.constants import CLOSED, NEW, OPEN
 from edc_notification.site_notifications import site_notifications
 
 from ..utils import reset_and_delete_action_item
