@@ -1,15 +1,9 @@
+from clinicedc_constants import DEAD, GRADE5, HIGH_PRIORITY, LTFU, YES
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 
 from edc_action_item.action_with_notification import ActionWithNotification
 from edc_action_item.site_action_items import site_action_items
-from edc_adverse_event.constants import (
-    AE_FOLLOWUP_ACTION,
-    AE_INITIAL_ACTION,
-    DEATH_REPORT_ACTION,
-)
-from edc_constants.constants import DEAD, GRADE5, HIGH_PRIORITY, YES
-from edc_ltfu.constants import LOST_TO_FOLLOWUP
 from edc_notification.utils import get_email_contacts
 from edc_visit_schedule.utils import (
     OnScheduleError,
@@ -17,7 +11,13 @@ from edc_visit_schedule.utils import (
     get_onschedule_models,
 )
 
-from ..constants import ADVERSE_EVENT_ADMIN_SITE, ADVERSE_EVENT_APP_LABEL
+from ..constants import (
+    ADVERSE_EVENT_ADMIN_SITE,
+    ADVERSE_EVENT_APP_LABEL,
+    AE_FOLLOWUP_ACTION,
+    AE_INITIAL_ACTION,
+    DEATH_REPORT_ACTION,
+)
 
 
 class AeFollowupAction(ActionWithNotification):
@@ -88,7 +88,7 @@ class AeFollowupAction(ActionWithNotification):
 
     def update_next_actions_ltfu(self, next_actions=None):
         """Add Study termination to next_actions if LTFU."""
-        if self.reference_obj.outcome and self.reference_obj.outcome == LOST_TO_FOLLOWUP:
+        if self.reference_obj.outcome and self.reference_obj.outcome == LTFU:
             if not self.onschedule_models:
                 raise OnScheduleError(
                     f"Subject cannot be lost to followup. "
