@@ -1,7 +1,6 @@
+from clinicedc_constants import DEAD, GRADE5, YES
 from django import forms
 
-from edc_constants.constants import DEAD, GRADE5, YES
-
 from ..form_validators import AeFollowupFormValidator
 from ..utils import validate_ae_initial_outcome_date
 from .ae_modelform_mixin import AeModelFormMixin
