@@ -37,6 +37,6 @@ class AeHomeView(UrlRequestContextMixin, EdcViewMixin, NavbarViewMixin, Template
             ae_initial_changelist_url=ae_initial_changelist_url,
             death_report_changelist_url=death_report_changelist_url,
             death_report_listboard_url=death_report_listboard_url,
-            **self.add_url_to_context(new_key="ae_home_url", existing_key=self.url_name),
+            **{self.url_name: url_names.get(self.url_name)},
         )
         return super().get_context_data(**kwargs)
