@@ -1,12 +1,12 @@
 from typing import Any
 
+from clinicedc_constants import CLOSED, NEW, OPEN
 from django.contrib.sites.shortcuts import get_current_site
 from django.db.models.aggregates import Count
 from django.urls import reverse
 from django.views.generic import TemplateView
 
 from edc_action_item.models.action_item import ActionItem
-from edc_constants.constants import CLOSED, NEW, OPEN
 from edc_dashboard.view_mixins import EdcViewMixin
 from edc_navbar import NavbarViewMixin
 
@@ -38,9 +38,10 @@ class TmgHomeView(EdcViewMixin, NavbarViewMixin, TemplateView):
             .values("status", "site__name")
             .annotate(items=Count("status"))
         )
-        notices = []
-        for item in qs.order_by("status", "site__name"):
-            notices.append([item.get("site__name"), item.get("status"), item.get("items")])
+        notices = [
+            (item.get("site__name"), item.get("status"), item.get("items"))
+            for item in qs.order_by("status", "site__name")
+        ]
         new_count = ActionItem.objects.filter(
             action_type__name=AE_TMG_ACTION,
             site__name=get_current_site(request=self.request).name,
