@@ -19,9 +19,7 @@ INVALID_PREVIOUS_APPOINTMENT_NOT_UPDATED = "previous_appointment_not_updated"
 INVALID_PREVIOUS_VISIT_MISSING = "previous_visit_missing"
 INVALID_MISSED_APPT_NOT_ALLOWED = "invalid_missed_appt_not_allowed"
 INVALID_APPT_STATUS_AT_BASELINE = "invalid_appt_status_at_baseline"
-INVALID_SKIPPED_APPT_NOT_ALLOWED_AT_BASELINE = (
-    "invalid_skipped_appt_not_allowed_at_baseline"
-)
+INVALID_SKIPPED_APPT_NOT_ALLOWED_AT_BASELINE = "invalid_skipped_appt_not_allowed_at_baseline"
 INVALID_APPT_TIMING = "invalid_appt_timing"
 INVALID_APPT_TIMING_CRFS_EXIST = "invalid_appt_timing_crfs_exist"
 INVALID_APPT_TIMING_REQUISITIONS_EXIST = "invalid_appt_timing_requisitions_exist"
