@@ -8,11 +8,10 @@ from edc_appointment.constants import (
 
 
 def constants(request) -> dict:
-    dct = dict(
+    return dict(
         COMPLETE_APPT=COMPLETE_APPT,
         INCOMPLETE_APPT=INCOMPLETE_APPT,
         IN_PROGRESS_APPT=IN_PROGRESS_APPT,
         MISSED_APPT=MISSED_APPT,
         NEW_APPT=NEW_APPT,
     )
-    return dct
