@@ -3,20 +3,19 @@ from __future__ import annotations
 from datetime import datetime
 from zoneinfo import ZoneInfo
 
+from clinicedc_constants import NO
 from django.db import models
 from django.db.models import PROTECT
 from django.utils.translation import gettext_lazy as _
 
 from edc_appointment.utils import validate_date_is_on_clinic_day
 from edc_constants.choices import YES_NO
-from edc_constants.constants import NO
 from edc_facility.utils import get_health_facility_model
 
 __all__ = ["NextAppointmentCrfModelMixin"]
 
 
 class NextAppointmentCrfModelMixin(models.Model):
-
     offschedule_today = models.CharField(
         verbose_name=_("Is the subject going off schedule today?"),
         choices=YES_NO,
