@@ -20,7 +20,7 @@ class WindowPeriodModelMixin(models.Model):
     window_period_checks_enabled: bool = True
 
     def save(self: Any, *args, **kwargs) -> None:
-        if not kwargs.get("update_fields", None):
+        if not kwargs.get("update_fields"):
             self.raise_on_appt_datetime_not_in_window()
         super().save(*args, **kwargs)
 
@@ -30,13 +30,12 @@ class WindowPeriodModelMixin(models.Model):
             and self.appt_status != CANCELLED_APPT
             and self.appt_datetime
             and self.timepoint_datetime
-        ):
-            if not self.ignore_window_period:
-                try:
-                    raise_on_appt_datetime_not_in_window(self)
-                except AppointmentWindowError as e:
-                    msg = f"{e} Perhaps catch this in the form"
-                    raise AppointmentWindowError(msg)
+        ) and not self.ignore_window_period:
+            try:
+                raise_on_appt_datetime_not_in_window(self)
+            except AppointmentWindowError as e:
+                msg = f"{e} Perhaps catch this in the form"
+                raise AppointmentWindowError(msg) from e
 
     class Meta:
         abstract = True
