@@ -7,13 +7,14 @@ class SitesListFilter(SimpleListFilter):
     title = "Site"
     parameter_name = "site_name"
 
-    def lookups(self, request, model_admin):
-        sites = []
-        for site in Site.objects.all().order_by("name"):
-            sites.append((site.name, site.name.replace("_", " ").title()))
+    def lookups(self, request, model_admin):  # noqa: ARG002
+        sites = [
+            (site.name, site.name.replace("_", " ").title())
+            for site in Site.objects.all().order_by("name")
+        ]
         return tuple(sites)
 
-    def queryset(self, request, queryset):
+    def queryset(self, request, queryset):  # noqa: ARG002
         """Returns a queryset if the site name is in the list of sites"""
         qs = None
         if self.value():
@@ -25,11 +26,11 @@ class CountriesListFilter(SimpleListFilter):
     title = "Country"
     parameter_name = "country_name"
 
-    def lookups(self, request, model_admin):
+    def lookups(self, request, model_admin):  # noqa: ARG002
         countries = set(s.siteprofile.country for s in Site.objects.all())
         return tuple((c, c.replace("_", " ").title()) for c in sorted(countries))
 
-    def queryset(self, request, queryset):
+    def queryset(self, request, queryset):  # noqa: ARG002
         """Returns a queryset if the country name is in a site's siteprofile,
         in the list of sites.
         """
