@@ -1,9 +1,9 @@
+from clinicedc_constants import INCOMPLETE
 from django.conf import settings
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from edc_constants.choices import DOCUMENT_STATUS
-from edc_constants.constants import INCOMPLETE
 
 from ..update_crf_status_for_instance import update_crf_status_for_instance
 
