@@ -1,7 +1,7 @@
+from clinicedc_constants import CLOSED, FEEDBACK, HIGH_PRIORITY, NEW, OPEN, RESOLVED
 from django import forms
 
 from edc_action_item.forms.action_item_form_mixin import ActionItemFormMixin
-from edc_constants.constants import CLOSED, FEEDBACK, HIGH_PRIORITY, NEW, OPEN, RESOLVED
 from edc_form_validators import FormValidator, FormValidatorMixin
 
 from ..constants import CLOSED_WITH_ACTION
