@@ -7,9 +7,7 @@ from ..models import QueryRule
 
 class QueryRuleFormValidator(FormValidator):
     def clean(self):
-        models = list(
-            set([obj.model for obj in self.cleaned_data.get("data_dictionaries")])
-        )
+        models = list(set([obj.model for obj in self.cleaned_data.get("data_dictionaries")]))
         if len(models) > 1:
             raise forms.ValidationError(
                 {"data_dictionaries": "Invalid. Select questions from one CRF only"}
