@@ -2,10 +2,10 @@ from __future__ import annotations
 
 from datetime import date, datetime
 
+from clinicedc_constants import GT, GTE, LT, LTE
 from django.conf import settings
 from django.core.exceptions import ValidationError
 
-from edc_constants.constants import GT, GTE, LT, LTE
 from edc_model import estimated_date_from_ago
 from edc_utils.text import convert_php_dateformat
 
