@@ -2,11 +2,10 @@ import csv
 import os
 from datetime import datetime
 
+from clinicedc_constants import CLOSED
 from django.core.exceptions import MultipleObjectsReturned
 from django.core.management.base import BaseCommand, CommandError
 
-from edc_constants.constants import CLOSED
-
 from ...models import ExportPlan, ExportReceipt, ExportTransaction
 
 
