@@ -20,17 +20,11 @@ class ExportHistoryManager(models.Manager):
 
         .. note:: If change_type == 'D', entire tx is still sent."""
         try:
-            ready_to_export_transaction = (
-                force_export or instance.ready_to_export_transaction
-            )
+            ready_to_export_transaction = force_export or instance.ready_to_export_transaction
         except AttributeError as attribute_error:
-            if str(attribute_error).endswith(
-                "has no attribute 'ready_to_export_transaction'"
-            ):
+            if str(attribute_error).endswith("has no attribute 'ready_to_export_transaction'"):
                 ready_to_export_transaction = True
             else:
                 raise
         if ready_to_export_transaction:
-            self.obj_creator.create(
-                model_obj=instance, change_type=change_type, using=using
-            )
+            self.obj_creator.create(model_obj=instance, change_type=change_type, using=using)
