@@ -7,7 +7,7 @@ navbar.register(
         name="export",
         label="Export",
         fa_icon="fa-file-export",
-        url_name="edc_export:home_url",
+        url_with_namespace="edc_export:home_url",
         codename="edc_navbar.nav_export",
     )
 )
@@ -16,7 +16,7 @@ navbar.register(
     NavbarItem(
         name="data_request",
         label="Export Admin",
-        url_name="edc_export:admin:index",
+        url_with_namespace="edc_export:admin:index",
         codename="edc_navbar.nav_export",
     )
 )
