@@ -23,9 +23,7 @@ def run_form_runners(
         for app_config in django_apps.get_app_configs():
             if app_config.name in app_labels:
                 for model_cls in app_config.get_models():
-                    if not model_cls._meta.label_lower.split(".")[1].startswith(
-                        "historical"
-                    ):
+                    if not model_cls._meta.label_lower.split(".")[1].startswith("historical"):
                         model_names.append(model_cls._meta.label_lower)
     if not model_names:
         raise FormRunnerError("Nothing to do.")
