@@ -12,7 +12,7 @@ if TYPE_CHECKING:
     from edc_crf.model_mixins import CrfModelMixin
     from edc_metadata.models import CrfMetadata, RequisitionMetadata
 
-    class Model(CrfModelMixin, models.Model): ...  # noqa
+    class Model(CrfModelMixin, models.Model): ...
 
 
 register = template.Library()
