@@ -1,7 +1,6 @@
+from clinicedc_constants import NOT_APPLICABLE, OTHER
 from django.forms import ValidationError
 
-from edc_constants.constants import NOT_APPLICABLE, OTHER
-
 from .base_form_validator import (
     APPLICABLE_ERROR,
     NOT_APPLICABLE_ERROR,
