@@ -1,9 +1,8 @@
 from typing import Any
 
+from clinicedc_constants import OTHER
 from django.forms import ValidationError
 
-from edc_constants.constants import OTHER
-
 from .base_form_validator import NOT_REQUIRED_ERROR, REQUIRED_ERROR, BaseFormValidator
 
 
