@@ -1,8 +1,7 @@
+from clinicedc_constants import EQ, NOT_APPLICABLE
 from django.db import models
 
-from edc_constants.constants import NOT_APPLICABLE
 from edc_lab.choices import GLUCOSE_UNITS_NA, RESULT_QUANTIFIER
-from edc_lab.constants import EQ
 
 from ..constants import GLUCOSE_HIGH_READING
 
