@@ -1,7 +1,6 @@
+from clinicedc_constants import YES
 from django.apps import apps as django_apps
 
-from edc_constants.constants import YES
-
 from ..identifiers import Prefix as IdentifierPrefix
 from .aliquot_creator import AliquotCreator
 from .primary_aliquot import PrimaryAliquot
