@@ -1,3 +1,4 @@
+from clinicedc_constants import NOT_APPLICABLE
 from django.conf import settings
 from django.db import models
 from django.db.models import UniqueConstraint
@@ -5,7 +6,6 @@ from django.utils import timezone
 
 from edc_consent.model_mixins import RequiresConsentFieldsModelMixin
 from edc_constants.choices import YES_NO
-from edc_constants.constants import NOT_APPLICABLE
 from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_metadata.model_mixins.updates import UpdatesRequisitionMetadataModelMixin
 from edc_model.models import HistoricalRecords, InitialsField, OtherCharField
