@@ -12,7 +12,7 @@ dashboard_templates = dict(
     edc_lab_base_listboard_template="edc_lab_dashboard/base_listboard.html",
     edc_lab_listboard_template="edc_lab_dashboard/listboard.html",
     manage_box_listboard_template="edc_lab_dashboard/manage_box_listboard.html",
-    manage_manifest_listboard_template="edc_lab_dashboard/manage_manifest_listboard.html",  # noqa
+    manage_manifest_listboard_template="edc_lab_dashboard/manage_manifest_listboard.html",
     manifest_listboard_template="edc_lab_dashboard/manifest_listboard.html",
     pack_listboard_template="edc_lab_dashboard/pack_listboard.html",
     process_listboard_template="edc_lab_dashboard/process_listboard.html",
