@@ -10,13 +10,13 @@ from .base_box_item_listboard_view import BaseBoxItemListboardView
 
 class ManageBoxListboardView(BaseBoxItemListboardView):
     action_name = "manage"
-    form_action_url = "manage_box_item_form_action_url"
-    listboard_url = "manage_box_listboard_url"
+    form_action_url = "manage_box_item_form_action_url"  # url_name
+    listboard_url = "manage_box_listboard_url"  # url_name
     listboard_template = "manage_box_listboard_template"
-    verify_box_listboard_url = "verify_box_listboard_url"
+    verify_box_listboard_url = "verify_box_listboard_url"  # url_name
     listboard_model = "edc_lab.boxitem"
     navbar_selected_item = "pack"
-    search_form_url = "manage_box_listboard_url"
+    search_form_url = "manage_box_listboard_url"  # url_name
 
     @property
     def url_kwargs(self):
