@@ -1,8 +1,8 @@
 from typing import Any
 
+from clinicedc_constants import OPEN
 from django.apps import apps as django_apps
 
-from edc_constants.constants import OPEN
 from edc_lab.constants import SHIPPED
 from edc_lab.models import Manifest
 
