@@ -1,16 +1,11 @@
+from clinicedc_constants import EQ, FASTING, MILLIGRAMS_PER_DECILITER, MILLIMOLES_PER_LITER
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
 
 from edc_constants.choices import FASTING_CHOICES, YES_NO
-from edc_constants.constants import FASTING
 from edc_glucose.constants import GLUCOSE_HIGH_READING
 from edc_lab.choices import RESULT_QUANTIFIER
-from edc_lab.constants import EQ
-from edc_reportable import (
-    MILLIGRAMS_PER_DECILITER,
-    MILLIMOLES_PER_LITER,
-    MILLIMOLES_PER_LITER_DISPLAY,
-)
+from edc_reportable.units import MILLIMOLES_PER_LITER_DISPLAY
 
 from ..model_mixin_factories import reportable_result_model_mixin_factory
 
