@@ -1,5 +1,3 @@
-from typing import Optional
-
 from django.apps import AppConfig
 from django.core.management.color import color_style
 
@@ -13,25 +11,21 @@ style = color_style()
 class PreloadData:
     def __init__(
         self,
-        list_data: dict[str, list[tuple[str | int, str]]] = None,
-        model_data: dict = None,
-        list_data_model_name: str = None,
+        list_data: dict[str, list[tuple[str | int, str]]],
+        model_data: dict | None = None,
+        list_data_model_name: str | None = None,
         apps: AppConfig = None,
     ) -> None:
         self.list_data = list_data
         self.model_data = model_data or {}
         self.item_count = 0
         if self.list_data:
-            self.item_count += self.load_list_data(
-                model_name=list_data_model_name, apps=apps
-            )
+            self.item_count += self.load_list_data(model_name=list_data_model_name, apps=apps)
         if self.model_data:
             self.item_count += self.load_model_data()
 
-    def load_list_data(
-        self, model_name: str = None, apps: Optional[AppConfig] = None
-    ) -> int:
+    def load_list_data(self, model_name: str, apps: AppConfig | None = None) -> int:
         return load_list_data(self.list_data, model_name=model_name, apps=apps)
 
-    def load_model_data(self, apps: Optional[AppConfig] = None) -> int:
+    def load_model_data(self, apps: AppConfig | None = None) -> int:
         return load_model_data(self.model_data, apps=apps)
