@@ -1,7 +1,7 @@
+import django.utils.timezone
 from django.db import models
 
 from edc_identifier.model_mixins import UniqueSubjectIdentifierFieldMixin
-from edc_utils import get_utcnow
 
 from .locator_methods_model_mixin import LocatorMethodsModelMixin
 from .subject_contact_fields_mixin import SubjectContactFieldsMixin
@@ -30,7 +30,7 @@ class LocatorModelMixin(
     This model is used in ListboardViews.
     """
 
-    report_datetime = models.DateTimeField(default=get_utcnow)
+    report_datetime = models.DateTimeField(default=django.utils.timezone.now)
 
     objects = LocatorManager()
 
