@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Type
-
 from .metadata_getter import MetadataGetter, MetadataValidator
 
 
@@ -12,4 +10,4 @@ class CrfMetadataValidator(MetadataValidator):
 class CrfMetadataGetter(MetadataGetter):
     metadata_model: str = "edc_metadata.crfmetadata"
 
-    metadata_validator_cls: Type[CrfMetadataValidator] = CrfMetadataValidator
+    metadata_validator_cls: type[CrfMetadataValidator] = CrfMetadataValidator
