@@ -1,4 +1,7 @@
+import contextlib
+
 from django import dispatch
+from django.core.exceptions import ObjectDoesNotExist
 from django.db.models import expressions
 from simple_history import signals
 
@@ -17,12 +20,14 @@ def remove_f_expressions(sender, instance, history_instance, **kwargs) -> None:
     """
     f_expression_fields = []
     for field in history_instance._meta.fields:
-        field_value = getattr(history_instance, field.name)
+        with contextlib.suppress(ObjectDoesNotExist):
+            field_value = getattr(history_instance, field.name)
         if isinstance(field_value, expressions.BaseExpression):
             f_expression_fields.append(field.name)
 
     if f_expression_fields:
         instance.refresh_from_db()
         for field_name in f_expression_fields:
-            field_value = getattr(instance, field_name)
+            with contextlib.suppress(ObjectDoesNotExist):
+                field_value = getattr(instance, field_name)
             setattr(history_instance, field_name, field_value)
