@@ -1,14 +1,12 @@
 from typing import Any
 
-from django.apps import apps as django_apps
-
-from .get_default_navbar import get_default_navbar
 from .site_navbars import site_navbars
+from .utils import get_default_navbar_name
 
 
 class NavbarViewMixin:
     navbar_selected_item = None
-    navbar_name = get_default_navbar()
+    navbar_name = get_default_navbar_name()
 
     def get_context_data(self, **kwargs) -> dict[str, Any]:
         """Add rendered navbar <navbar_name> to the context for
@@ -16,18 +14,17 @@ class NavbarViewMixin:
 
         Also adds the "default" navbar.
         """
-        kwargs = self.get_navbar_context_data(kwargs)
+        kwargs = self.get_context_data_for_navbars(kwargs)
         return super().get_context_data(**kwargs)
 
     def get_navbar_name(self):
         return self.navbar_name
 
-    def get_navbar_context_data(self, context) -> dict:
+    def get_context_data_for_navbars(self, context) -> dict:
         navbar = site_navbars.get_navbar(name=self.get_navbar_name())
         navbar.set_active(self.get_navbar_selected(**context))
         context.update(navbar=navbar)
-        app_config = django_apps.get_app_config("edc_navbar")
-        default_navbar_name = app_config.default_navbar_name
+        default_navbar_name = get_default_navbar_name()
         if default_navbar_name and self.get_navbar_name() != default_navbar_name:
             default_navbar = site_navbars.get_navbar(name=default_navbar_name)
             default_navbar.set_active(self.navbar_selected_item)
@@ -36,5 +33,5 @@ class NavbarViewMixin:
             )
         return context
 
-    def get_navbar_selected(self, **kwargs) -> str:
+    def get_navbar_selected(self, **kwargs) -> str:  # noqa: ARG002
         return self.navbar_selected_item
