@@ -1,6 +1,7 @@
+from clinicedc_constants import HIGH_PRIORITY
+
 from edc_action_item.action_with_notification import ActionWithNotification
 from edc_adverse_event.constants import DEATH_REPORT_ACTION
-from edc_constants.constants import HIGH_PRIORITY
 from edc_ltfu.constants import LTFU_ACTION
 from edc_unblinding.constants import UNBLINDING_REVIEW_ACTION
 
