@@ -7,7 +7,7 @@ from django.apps import apps as django_apps
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import transaction
 
-from edc_utils import formatted_datetime, to_utc
+from edc_utils.text import formatted_datetime
 from edc_visit_schedule.site_visit_schedules import site_visit_schedules
 
 from .exceptions import OffstudyError
@@ -33,9 +33,9 @@ def get_offstudy_model_cls() -> OffstudyModelMixin:
 
 
 def raise_if_offstudy(
+    subject_identifier: str,
+    report_datetime: datetime,
     source_obj: Model | None = None,
-    subject_identifier: str = None,
-    report_datetime: datetime = None,
 ) -> OffstudyModelMixin | None:
     """Returns None or raises OffstudyError"""
     obj = None
@@ -43,7 +43,7 @@ def raise_if_offstudy(
         with transaction.atomic():
             obj = get_offstudy_model_cls().objects.get(
                 subject_identifier=subject_identifier,
-                offstudy_datetime__lt=to_utc(report_datetime),
+                offstudy_datetime__lt=report_datetime,
             )
     except ObjectDoesNotExist:
         pass
