@@ -1,10 +1,9 @@
 import contextlib
 
 import pandas as pd
+from clinicedc_constants import NO, YES
 from django.conf import settings
 
-from edc_constants.constants import NO, YES
-
 
 class Helper:
     to_dataframe_cls = None
