@@ -1,7 +1,6 @@
 import numpy as np
 import pandas as pd
-
-from edc_constants.constants import YES
+from clinicedc_constants import YES
 
 from ..mappings import yes_no
 from .table import Table
