@@ -9,7 +9,5 @@ def convert_timedelta_from_model(source_df: pd.DataFrame, model_cls) -> pd.DataF
         if field_cls.get_internal_type() in timedelta_datatypes:
             date_cols.append(field_cls.name)
     if date_cols:
-        source_df[date_cols] = source_df[date_cols].apply(
-            pd.to_timedelta, errors="coerce"
-        )
+        source_df[date_cols] = source_df[date_cols].apply(pd.to_timedelta, errors="coerce")
     return source_df
