@@ -16,7 +16,6 @@ from edc_utils.date import to_local
 
 @admin.register(Confirmation, site=edc_pharmacy_admin)
 class ConfirmationAdmin(ModelAdminMixin, SimpleHistoryAdmin):
-
     change_list_title = "Pharmacy: Confirmed stock"
     change_form_title = "Pharmacy: Confirmed stock"
     history_list_display = ()
@@ -26,7 +25,7 @@ class ConfirmationAdmin(ModelAdminMixin, SimpleHistoryAdmin):
 
     form = ConfirmationForm
 
-    actions = ["delete_selected"]
+    actions = ("delete_selected",)
 
     fieldsets = (
         (
@@ -56,18 +55,15 @@ class ConfirmationAdmin(ModelAdminMixin, SimpleHistoryAdmin):
 
     def get_list_display(self, request):
         fields = super().get_list_display(request)
-        fields = remove_fields_for_blinded_users(request, fields)
-        return fields
+        return remove_fields_for_blinded_users(request, fields)
 
     def get_list_filter(self, request):
         fields = super().get_list_filter(request)
-        fields = remove_fields_for_blinded_users(request, fields)
-        return fields
+        return remove_fields_for_blinded_users(request, fields)
 
     def get_search_fields(self, request):
         fields = super().get_search_fields(request)
-        fields = remove_fields_for_blinded_users(request, fields)
-        return fields
+        return remove_fields_for_blinded_users(request, fields)
 
     @admin.display(description="CONFIRMED #", ordering="confirmation_identifier")
     def identifier(self, obj):
