@@ -12,12 +12,11 @@ class Manager(models.Manager):
 
 
 class Medication(BaseUuidModel):
-
     name = models.CharField(max_length=35, unique=True)
 
     display_name = models.CharField(max_length=50, unique=True)
 
-    notes = models.TextField(max_length=250, null=True, blank=True)
+    notes = models.TextField(max_length=250, default="", blank=True)
 
     objects = Manager()
 
@@ -38,9 +37,9 @@ class Medication(BaseUuidModel):
     class Meta(BaseUuidModel.Meta):
         verbose_name = "Medication"
         verbose_name_plural = "Medications"
-        constraints = [
+        constraints = (
             UniqueConstraint(
                 fields=["name", "display_name"],
                 name="%(app_label)s_%(class)s_name_uniq",
-            )
-        ]
+            ),
+        )
