@@ -11,12 +11,8 @@ def adjust_previous_end_datetime(
     user_modified: str | None = None,
     modified: str | None = None,
 ) -> None:
-    if previous_obj.refill_end_datetime != refill_start_datetime - relativedelta(
-        minutes=1
-    ):
-        previous_obj.refill_end_datetime = refill_start_datetime - relativedelta(
-            minutes=1
-        )
+    if previous_obj.refill_end_datetime != refill_start_datetime - relativedelta(minutes=1):
+        previous_obj.refill_end_datetime = refill_start_datetime - relativedelta(minutes=1)
         previous_obj.number_of_days = (
             previous_obj.refill_end_datetime - previous_obj.refill_start_datetime
         ).days
