@@ -11,9 +11,9 @@ def format_qty(qty: Decimal, container: Container):
     qty = 0 if qty is None else qty
     if container.qty_decimal_places == 0:
         return str(int(qty))
-    elif container.qty_decimal_places == 1:
-        return "{:0.1f}".format(qty)
-    return "{:0.2f}".format(qty)
+    if container.qty_decimal_places == 1:
+        return f"{qty:0.1f}"
+    return f"{qty:0.2f}"
 
 
 __all__ = ["format_qty"]
