@@ -18,9 +18,7 @@ class LabelConfiguration(BaseUuidModel):
         help_text="Name of configuration registered with site_label_config.",
     )
 
-    label_specification = models.ForeignKey(
-        LabelSpecification, on_delete=models.PROTECT
-    )
+    label_specification = models.ForeignKey(LabelSpecification, on_delete=models.PROTECT)
 
     requires_allocation = models.BooleanField(
         verbose_name="Configuration is for a subject label", default=False
