@@ -1,4 +1,4 @@
-from edc_constants.constants import NOT_AVAILABLE, PENDING
+from clinicedc_constants import NOT_AVAILABLE, PENDING
 
 NOTE_STATUSES = (
     (PENDING, "Data is pending"),
