@@ -1,5 +1,3 @@
-from typing import Dict
-
 RANDOMIZED = "RANDOMIZED"
 
 ACTIVE = "active"
@@ -7,8 +5,8 @@ ACTIVE_NAME = "Active: "
 PLACEBO = "placebo"
 PLACEBO_NAME = "Placebo: "
 DEFAULT = "default"
-DEFAULT_ASSIGNMENT_MAP: Dict[str, int] = {ACTIVE: 1, PLACEBO: 2}
-DEFAULT_ASSIGNMENT_DESCRIPTION_MAP: Dict[str, str] = {
+DEFAULT_ASSIGNMENT_MAP: dict[str, int] = {ACTIVE: 1, PLACEBO: 2}
+DEFAULT_ASSIGNMENT_DESCRIPTION_MAP: dict[str, str] = {
     ACTIVE: "Active",
     PLACEBO: "Placebo",
 }
