@@ -7,12 +7,11 @@ from django_crypto_fields.fields import EncryptedCharField
 from edc_model.models import HistoricalRecords
 from edc_sites.managers import CurrentSiteManager
 
+from .exceptions import RandomizationListModelError
 from .randomizer import RandomizationError
 from .site_randomizers import site_randomizers
 
-
-class RandomizationListModelError(Exception):
-    pass
+__all__ = ["RandomizationListManager", "RandomizationListModelMixin"]
 
 
 class RandomizationListManager(models.Manager):
@@ -72,7 +71,7 @@ class RandomizationListModelMixin(models.Model):
     def save(self, *args, **kwargs):
         self.randomizer_name = self.randomizer_cls.name
         try:
-            self.assignment_description
+            self.assignment_description  # noqa: B018
         except RandomizationError as e:
             raise RandomizationListModelError(e) from e
         try:
