@@ -3,7 +3,7 @@ import sys
 from dataclasses import dataclass
 
 from django.conf import settings
-from django.core.checks import Error, Warning
+from django.core.checks import Error, Warning  # noqa: A004
 from django.core.exceptions import ImproperlyConfigured
 from django.core.management import color_style
 
@@ -57,7 +57,7 @@ def randomizationlist_check(app_configs, **kwargs) -> list:
         ):
             error_msgs = randomizer.verify_list()
             for error_msg in error_msgs:
-                errors.append(error.cls(error_msg, hint=None, obj=None, id=error.id))
+                errors.append(error.cls(error_msg, hint=None, obj=None, id=error.id))  # noqa: PERF401
         if not settings.DEBUG:
             if not randomizer.get_randomizationlist_path().is_relative_to(settings.ETC_DIR):
                 errors.append(
