@@ -1,14 +1,12 @@
-from edc_constants.constants import FEMALE, MALE
-
-from ...adult_age_options import adult_age_options
-from ...formula import Formula
-from ...units import (
+from clinicedc_constants import (
     CELLS_PER_MILLIMETER_CUBED,
     EGFR_UNITS,
+    FEMALE,
     FEMTOLITERS_PER_CELL,
     GRAMS_PER_DECILITER,
     GRAMS_PER_LITER,
     IU_LITER,
+    MALE,
     MICROMOLES_PER_LITER,
     MILLIGRAMS_PER_DECILITER,
     MILLIGRAMS_PER_LITER,
@@ -19,6 +17,9 @@ from ...units import (
     TEN_X_9_PER_LITER,
 )
 
+from ...adult_age_options import adult_age_options
+from ...formula import Formula
+
 __all__ = ["normal_data"]
 
 normal_data = {
