@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Type
+from typing import TYPE_CHECKING
 
 from django.apps import apps as django_apps
 
@@ -8,5 +8,5 @@ if TYPE_CHECKING:
     from edc_reportable.models import MolecularWeight
 
 
-def molecular_weight_model_cls() -> Type[MolecularWeight]:
+def molecular_weight_model_cls() -> type[MolecularWeight]:
     return django_apps.get_model("edc_reportable", "MolecularWeight")
