@@ -7,10 +7,9 @@ navbar_item = NavbarItem(
     label="Review",
     title="Subject Review",
     codename="edc_review_dashboard.view_subject_review_listboard",
-    url_name="subject_review_listboard_url",
+    url_names_key="subject_review_listboard_url",
 )
 
-
 navbar.register(navbar_item)
 
 site_navbars.register(navbar)
