@@ -37,6 +37,16 @@ urlpatterns = [
     ),
 ]
 
-url_names.register(url="requisition_print_actions_url", namespace=app_name)
-url_names.register(url="requisition_verify_actions_url", namespace=app_name)
-url_names.register(url="refresh_metadata_actions_url", namespace=app_name)
+url_names.register(
+    key="requisition_print_actions_url",
+    url="requisition_print_actions_url",
+    namespace=app_name,
+)
+url_names.register(
+    key="requisition_verify_actions_url",
+    url="requisition_verify_actions_url",
+    namespace=app_name,
+)
+url_names.register(
+    key="refresh_metadata_actions_url", url="refresh_metadata_actions_url", namespace=app_name
+)
