@@ -19,9 +19,10 @@ class CrfButton(DashboardModelButton):
     @property
     def disabled(self) -> str:
         disabled = "disabled"
-        if (not self.model_obj and self.perms.add) or self.perms.change:
+        if (
+            (not self.model_obj and self.perms.add)
+            or self.perms.change
+            or (self.perms.view and self.model_obj)
+        ):
             disabled = ""
-        elif self.perms.view:
-            if self.model_obj:
-                disabled = ""
         return disabled
