@@ -8,14 +8,15 @@ from zoneinfo import ZoneInfo
 from dateutil.relativedelta import relativedelta
 from django.conf import settings
 
-from edc_utils import to_local
+from edc_utils.date import to_local
 
 
 class WindowPeriod:
     def __init__(
         self,
-        rlower: relativedelta = None,
-        rupper: relativedelta = None,
+        *,
+        rlower: relativedelta,
+        rupper: relativedelta,
         timepoint: Decimal | None = None,
         base_timepoint: Decimal | None = None,
         no_floor: bool | None = None,
