@@ -1,8 +1,8 @@
+from clinicedc_constants import ALIVE, NOT_APPLICABLE, YES
 from django.db import models
 from django.utils import timezone
 
 from edc_constants.choices import ALIVE_DEAD_UNKNOWN_NA_MISSED, YES_NO
-from edc_constants.constants import ALIVE, NOT_APPLICABLE, YES
 from edc_model.validators import date_not_future, datetime_not_future
 from edc_model_fields.fields import OtherCharField
 from edc_protocol.validators import (
